Public Class fmMain
    Private wclTimelineChannel As wclTimelineChannel
    Private FActivity As wclUserActivity

    Private Sub CheckParams()
        Dim Args As String() = Environment.GetCommandLineArgs()
        'Check application params.
        If Args.Length > 1 Then
            Dim Str As String = Args(1)
            'Make sure it is correct params.
            Dim p As Int32 = Str.IndexOf(":")
            If p <> -1 Then
                'Extract ActivityID.
                Str = Str.Substring(p + 1, Str.Length - p - 1)
                'Start activity with given ID.
                If Str <> "" Then
                    Dim Res As Int32 = wclTimelineChannel.Open()
                    If Res = wclErrors.WCL_E_SUCCESS Then
                        Res = wclTimelineChannel.CreateActivity(Str, FActivity)
                        If Res = wclErrors.WCL_E_SUCCESS Then
                            MessageBox.Show("Application started from Activity. Activity opened.")
                            laState.Text = "Published"
                            edActivityId.Text = Str
                            edDescription.Text = FActivity.Description
                            edDisplayText.Text = FActivity.DisplayText
                            laProtocol.Text = FActivity.Protocol
                            edTitle.Text = FActivity.Title
                        Else
                            wclTimelineChannel.Close()
                        End If
                    End If
                End If
            End If
        End If
    End Sub

    Private Sub fmMain_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        wclTimelineChannel = New wclTimelineChannel()

        edActivationProtocol.Text = "uatest"
        edActivationProtocolDescription.Text = "User Activity Test"
        edActivityId.Text = "TestUserActivity"
        laState.Text = "<No activity>"
        laProtocol.Text = "<No activity>"

        edDisplayText.Text = "Hello activities (Test)"
        edDescription.Text = "Test User Activity"

        FActivity = Nothing

        CheckParams()
    End Sub

    Private Sub btRegisterProtocol_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btRegisterProtocol.Click
        If edActivationProtocol.Text = "" Then
            MessageBox.Show("Activation protocol can not be an empty string")
        Else
            If edActivationProtocolDescription.Text = "" Then
                MessageBox.Show("Protocol description can not be an empty string")
            Else
                Dim Res As Int32 = wclTimelineChannel.RegisterProtocol(edActivationProtocol.Text, edActivationProtocolDescription.Text)
                If Res <> wclErrors.WCL_E_SUCCESS Then
                    MessageBox.Show("Failed to register protocol: " + Res.ToString("X8"))
                Else
                    MessageBox.Show("Protocol registered")
                End If
            End If
        End If
    End Sub

    Private Sub btUnregisterprotocol_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btUnregisterprotocol.Click
        If edActivationProtocol.Text = "" Then
            MessageBox.Show("Activation protocol can not be an empty string")
        Else
            Dim Res As Int32 = wclTimelineChannel.UnregisterProtocol(edActivationProtocol.Text)
            If Res <> wclErrors.WCL_E_SUCCESS Then
                MessageBox.Show("Failed to unregister protocol: " + Res.ToString("X8"))
            Else
                MessageBox.Show("Protocol unregistered")
            End If
        End If
    End Sub

    Private Sub btOpen_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btOpen.Click
        Dim Res As Int32 = wclTimelineChannel.Open()
        If Res <> wclErrors.WCL_E_SUCCESS Then
            MessageBox.Show("Open channel failed: 0x" + Res.ToString("X8"))
        Else
            MessageBox.Show("Channel opened.")
        End If
    End Sub

    Private Sub btClose_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btClose.Click
        DestroyActivity()

        Dim Res As Int32 = wclTimelineChannel.Close()
        If Res <> wclErrors.WCL_E_SUCCESS Then
            MessageBox.Show("Close channel failed: 0x" + Res.ToString("X8"))
        Else
            MessageBox.Show("Channel closed.")
        End If
    End Sub

    Private Sub fmMain_FormClosed(ByVal sender As System.Object, ByVal e As System.Windows.Forms.FormClosedEventArgs) Handles MyBase.FormClosed
        DestroyActivity()
        wclTimelineChannel.Close()
        wclTimelineChannel.Dispose()
        wclTimelineChannel = Nothing
    End Sub

    Private Sub btCreateActivity_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btCreateActivity.Click
        If Not (FActivity Is Nothing) Then
            MessageBox.Show("Activity has already been created")
        Else
            Dim Res As Int32 = wclTimelineChannel.CreateActivity(edActivityId.Text, FActivity)
            If Res <> wclErrors.WCL_E_SUCCESS Then
                MessageBox.Show("Create activity failed: 0x" + Res.ToString("X8"))
            Else
                MessageBox.Show("Activity has been created")

                Select Case FActivity.State
                    Case wclUserActivityState.asNew
                        laState.Text = "New"
                        laProtocol.Text = edActivationProtocol.Text

                    Case wclUserActivityState.asPublished
                        laState.Text = "Published"
                        edDescription.Text = FActivity.Description
                        edDisplayText.Text = FActivity.DisplayText
                        laProtocol.Text = FActivity.Protocol
                        edTitle.Text = FActivity.Title
                End Select
            End If
        End If
    End Sub

    Private Sub btBeginSession_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btBeginSession.Click
        If FActivity Is Nothing Then
            MessageBox.Show("Activity has not been created")
        Else
            If FActivity.Active Then
                MessageBox.Show("Session is active")
            Else
                FActivity.Protocol = edActivationProtocol.Text
                FActivity.Params = FActivity.Id
                FActivity.Description = edDescription.Text
                FActivity.DisplayText = edDisplayText.Text
                FActivity.Title = edTitle.Text

                Dim Res As Int32 = FActivity.BeginSession()
                If Res <> wclErrors.WCL_E_SUCCESS Then
                    MessageBox.Show("Begin session failed: 0x" + Res.ToString("X8"))
                Else
                    MessageBox.Show("Session has been started")
                End If
            End If
        End If
    End Sub

    Private Sub btDestroyActivity_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btDestroyActivity.Click
        If FActivity Is Nothing Then
            MessageBox.Show("Activity has not been created")
        Else
            DestroyActivity()

            MessageBox.Show("Activity released")
        End If
    End Sub

    Private Sub btEndSession_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btEndSession.Click
        If FActivity Is Nothing Then
            MessageBox.Show("Activity has not been created")
        Else
            Dim Res As Int32 = FActivity.EndSession()
            If Res <> wclErrors.WCL_E_SUCCESS Then
                MessageBox.Show("End session failed: 0x" + Res.ToString("X8"))
            Else
                MessageBox.Show("Session has been stopped")
            End If
        End If
    End Sub

    Private Sub DestroyActivity()
        If Not (FActivity Is Nothing) Then
            FActivity.Dispose()
            FActivity = Nothing

            laState.Text = "<No activity>"
            laProtocol.Text = "<No activity>"
        End If
    End Sub
End Class
